In-line maths: $e^{\pi i} + 1 = 0$

Here's a single-line equation:

$$$
E = mc^2
$$$

Here are multiple lines:

$$$
x = 4
y = 2x + 1
\therefore y = 9
$$$

Here's are multiple lines aligned:

$$$
2x - 5 &= 8
3x + 9y &= -12
$$$